# Footnote

A document footnote.

**Type:** object

## Properties

- **footnoteId** (string): The ID of the footnote.
- **content** (array of [StructuralElement](structuralelement.md)): The contents of the footnote. The indexes for a footnote's content begin at zero.
